@@ -2,6 +2,7 @@ import datetime
 import os
 import zlib
 from pathlib import Path
+import os
 
 import pandas as pd
 from tensorflow.keras.callbacks import CSVLogger, TensorBoard, Callback, ModelCheckpoint
@@ -9,12 +10,17 @@ from tensorflow.keras.callbacks import CSVLogger, TensorBoard, Callback, ModelCh
 from ..constants import RESULTS_DIR
 
 
-def get_logging_callbacks(params, experiment_id, experiment_name=None, results_path=RESULTS_DIR):
-    logger = ExperimentLogger(params, experiment_id, experiment_name, results_path)
+def get_logging_callbacks(params, experiment_id, param_id, experiment_name=None, results_path=RESULTS_DIR):
+    logger = ExperimentLogger(params, experiment_id, param_id, experiment_name, results_path)
     csv_logger = CSVLogger(logger.path / 'history.tsv', separator='\t', append=True)
     tensorboard = TensorBoard(log_dir=logger.tensorboard_path)
+
+    checkpoint_n = len(os.listdir(logger.checkpoints_path)) + 1
+    checkpoint_n = str(checkpoint_n).zfill(5)
+    checkpoint_n = f'{checkpoint_n}_checkpoint.h5'
+
     checkpointer = ModelCheckpoint(
-        logger.model_path / 'weights.h5', monitor='loss', verbose=0, save_best_only=False,
+        logger.checkpoints_path / checkpoint_n, monitor='loss', verbose=0, save_best_only=False,
         save_weights_only=True, mode='auto', save_freq='epoch'
     )
 
@@ -22,7 +28,7 @@ def get_logging_callbacks(params, experiment_id, experiment_name=None, results_p
 
 
 class ExperimentLogger(Callback):
-    def __init__(self, params, experiment_id, experiment_name=None, results_path=RESULTS_DIR):
+    def __init__(self, params, experiment_id, param_id, experiment_name=None, results_path=RESULTS_DIR):
         super(ExperimentLogger, self).__init__()
         if experiment_name is None:
             raise Exception('Please specify experiment name.')
@@ -37,7 +43,10 @@ class ExperimentLogger(Callback):
 
         # Create directory for the logs
         self.root_path = results_path
-        self.path = results_path / '_flat' /experiment_id
+        self.path = results_path / '_flat' / experiment_id
+        if not os.path.exists(self.path):
+            os.makedirs(self.path)
+        self.path = self.path / param_id
         if not os.path.exists(self.path):
             os.makedirs(self.path)
         # self.path = self.path / str(self.params_hash)
